#####plots and analyses for Architeuthis dux###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

archy<-read.csv("Adux.csv", header=TRUE) #reads in data
archy<-data.frame(archy)

###################Figure 14: Distribution of Top Total Length (m), Middle Mantle Length (m), and Bottom Mass (kg) for Architeuthis dux.

p1<-
  ggplot(archy, aes(Total.Length..m.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(bold("Figure 14")~italic("Architeuthis dux")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(archy$Total.Length..m.)))))

p2<-
  ggplot(archy, aes(Dorsal.Mantle.Length..m.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Mantle Length (m)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(archy$Dorsal.Mantle.Length..m.)))))

p3<-
  ggplot(archy, aes(Weight..kg.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Mass (kg)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(archy$Weight..kg.)))))

grid.arrange(p1,p2,p3, ncol=1)

####################skew, quantiles, summary stats ####################
require(moments)

quantile(archy$Total.Length..m., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (archy$Total.Length..m., na.rm = TRUE)
agostino.test(archy$Total.Length..m.)

quantile(archy$Dorsal.Mantle.Length..m., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (archy$Dorsal.Mantle.Length..m., na.rm = TRUE)
agostino.test(archy$Dorsal.Mantle.Length..m.)

quantile(archy$Weight..kg., probs = c(.75, .90, .95,.99, 1), na.rm = TRUE)
median (archy$Weight..kg., na.rm = TRUE)
agostino.test(archy$Weight..kg.)

####################By Ocean, Figure Not Shown####################
archy$Ocean<-as.factor(archy$Ocean)

ggplot(archy, aes(x=Total.Length..m.)) +
  geom_histogram(color="black", fill="lightsteelblue2", binwidth=2) +
  facet_grid(~Ocean)

atlantic<-subset(archy,Ocean =="Atlantic")
pacific<-subset(archy, Ocean="Pacific")
ks.test(atlantic$Total.Length..m., pacific$Total.Length..m.)

####################Figure 15: Linear regressions for Architeuthis dux. 
#Top Log10 Total Length (m) and Log10 Mass (kg). Log10 Mass=1.40+0.73 Log10 TL (p=0.0017, R2=0.22). 
#Middle Log10 Mantle Length (m) and Log10 Total Length (m). Log10=1.59+1.98 Log10 ML (p= 1.239e-09, R2=0.58). 
#Bottom Log10 Mantle Length (m) and Log10 Mass (kg). Log10 Mass=0.67+0.85 Log10 ML (p<2.2e-16, R2=0.72).
p4<-
  ggplot(archy, aes(log10(Total.Length..m.), log10(Weight..kg.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 15")~italic("Architeuthis dux")))+
  xlab(expression('Log'[10]~'Total Length (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(0,1.25)


p5<-
  ggplot(archy, aes(log10(Dorsal.Mantle.Length..m.), log10(Total.Length..m.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ylab(expression('Log'[10]~'Total Length (m)'))+
  xlab(expression('Log'[10]~'Mantle Length (m)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(-.75,1)

p6<-
  ggplot(archy, aes(log10(Dorsal.Mantle.Length..m.), log10(Weight..kg.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ylab(expression('Log'[10]~'Weight (kg)'))+
  xlab(expression('Log'[10]~'Mantle Length (m)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(-.5,1)

grid.arrange(p4,p5,p6, ncol=1)



allometric1<-lm(log10(archy$Weight..kg.)~log10(archy$Total.Length..m.))
allometric2<-lm(log10(archy$Total.Length..m.)~log10(archy$Dorsal.Mantle.Length..m.))
allometric3<-lm(log10(archy$Weight..kg.)~log10(archy$Dorsal.Mantle.Length..m.))


summary(allometric1)
summary(allometric2)
summary(allometric3)
