#####plots and analyses for Bathymodiolus giganteus###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

isopod<-read.csv("Bgiganteus.csv", header=TRUE) #reads in data
isopod<-data.frame(isopod)

adultsonly <- data.frame(subset(isopod, CL.cm >= 15, select=c(CL.cm, Sex)))

#####################Figure 4: Distribution of Carapace Length (cm) for 
#Top all individuals and Bottom just adults (carapace length >15 cm) for Bathynomus giganteus


p1<-ggplot(isopod, aes(CL.cm))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Carapace Length (cm)")+
  ggtitle(expression(bold("Figure 4")~italic("Bathynomus giganteus")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(isopod$CL.cm)))))

p2<-ggplot(adultsonly, aes(CL.cm))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Carapace Length for Adults Only (cm)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(adultsonly$CL.cm)))))

grid.arrange(p1,p2, ncol=1)

####################skew, quantiles, summary stats ####################
require(moments)

quantile(isopod$CL.cm, probs = c(.75, .90, .95, 1), na.rm = TRUE)

skewness(isopod$CL.cm,na.rm = TRUE)
agostino.test(isopod$CL.cm)

median(isopod$CL.cm,na.rm = TRUE)

quantile(adultsonly$CL.cm, probs = c(.75, .90, .95, 1), na.rm = TRUE)

skewness(adultsonly$CL.cm,na.rm = TRUE)
agostino.test(adultsonly$CL.cm)

median(adultsonly$CL.cm,na.rm = TRUE)

#####################Figure 5: Boxplots of Carapace Length (cm) for adult males and females of Bathynomus giganteus. 

adultsonly$Sex <- relevel(droplevels(adultsonly$Sex), ref = "F")
adultsonly$Sex <- factor(adultsonly$Sex, levels = c("F", "M"))

ggplot(adultsonly, aes(factor(Sex), CL.cm))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=TRUE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 5")~italic("Bathynomus giganteus")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Carapace Length for Adults Only (cm)")+
  xlab("Sex")

##analysis##

sex_CL<-lm(adultsonly$CL.cm~adultsonly$Sex)
summary(sex_CL)

aggregate(formula=adultsonly$CL.cm~adultsonly$Sex, FUN=mean)

