#####plots and analyses for Balaenoptera musculus  ###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)
require(plyr)

####################load and summarize data####################

bw_ind<-read.csv("Bmusculus_indian.csv", header=TRUE) #Indian Ocean
bw_na<-read.csv("Bmusculus_northatlantic.csv", header=TRUE) #North Atlantic
bw_np<-read.csv("Bmusculus_northpacific.csv", header=TRUE) #North Pacific
bw_shp<-read.csv("Bmusculus_shpcombined.csv", header=TRUE) #Southern Hemisphere Pelagic 
bw_shsg<-read.csv("Bmusculus_shsg.csv", header=TRUE) #Southern Hemisphere South Georgia
bw_sp<-read.csv("Bmusculus_southpacific.csv", header=TRUE) #South Pacific
bw_sa<-read.csv("Bmusculus_southatlantic.csv", header=TRUE) #South Atlantic

#R BIND#
allbw<-data.frame(rbind(bw_ind, bw_na, bw_np, bw_shp, bw_shsg, bw_sp, bw_sa))



allbw$Sx <- mapvalues(allbw$Sx, from = c("1", "2", "3", "0"), to = c("Male", "Female", "Hermaphrodite", "Unknown"))
allbw$Ocean <-mapvalues(allbw$Ocean, from = "Southern Hemisphere Pelagic", to ="S.H. Pelagic")
allbw$Ocean <- factor(allbw$Ocean, levels = c("South Pacific","Indian","South Atlantic", 
                                              "North Pacific", "North Atlantic", "S.H. Pelagic",
                                              "South Georgia", "South Shetlands"))

allbw_sex<-subset(allbw, Sx=="Male" | Sx=="Female")


##################Figure 43: Distribution of Total Length (m) for Balaenoptera musculus
ggplot(allbw, aes(Lengthmeters))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(atop(bold("Figure 43")*italic(" Balaenoptera musculus"))))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(allbw$Lengthmeters)))))

####################skew, quantiles, summary stats ####################


require(moments)

quantile(allbw$Lengthmeters, probs = c(.75, .90, .95, 1), na.rm = TRUE)
skewness(allbw$Lengthmeters, na.rm = TRUE)
agostino.test(allbw$Lengthmeters)

bigones<-subset(allbw,allbw$Lengthmeters>30)

##################Figure 44: Boxplots of Total Length (m) by region and sex for Balaenoptera musculus
Zissou <- c("darkorange", "lightsteelblue")

ggplot(allbw_sex, aes(factor(Sx),Lengthmeters, fill=Sx))+
  geom_boxplot(notch=FALSE)+
  scale_fill_manual(values=Zissou)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 44")~italic("Balaenoptera musculus")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"),
        axis.text.x=element_blank(), 
        strip.text.x=element_text(angle=90))+
  ylab("Total Length (m)")+
  xlab("")+
  facet_grid(.~Ocean)


##################Figure 45: Total Length (m) verses year by region for Balaenoptera musculus


ggplot(allbw, aes(Yr, Lengthmeters)) +
  geom_point(shape=., color="lightsteelblue3")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 45")~italic("Balaenoptera musculus")))+
  xlab("Year")+
  ylab("Total Length (m)")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"),strip.text.y=element_text(angle=0))+
  facet_grid(Ocean ~ ., scales="free_y")

#analysis
sizetest<-lm(allbw$Lengthmeters~
               allbw$Ocean+
               allbw$Yr+
               allbw$Sx+
               allbw$Ocean*allbw$Yr+
               allbw$Ocean*allbw$Sx+
               allbw$Yr+allbw$Sx)
summary(sizetest)
anova(sizetest)

