#####plots and analyses for Carcharodon carcharias###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

GWS<-read.csv("Ccarcharius_data.csv", header=TRUE) 
GWS<-data.frame(GWS)
GWS_Mat <- data.frame(subset(GWS, GWS$Maturity != "immature"))

GWS_news <-data.frame(read.csv("Ccarcharius_news.csv", header=TRUE)) 

###################Figure 18: Distribution of Total Length (m) for Carcharadon carcharias reported in Top literature and Bottom media


p1<-
  ggplot(GWS_Mat, aes(TLM))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(atop(bold("Figure 18")*italic(" Carcharadon carcharias"),"Literature")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(GWS_Mat$TLM)))))+
  xlim(0, 8)

p2<-
  ggplot(GWS_news, aes(TLM))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle("Estimates from Media")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(GWS_news$TLM)))))+
  xlim(0, 8)

grid.arrange(p1,p2, ncol=1)

####################skew, quantiles, summary stats ####################
require(moments)

quantile(GWS_Mat$TLM, probs = c(.75, .90, .95, 1), na.rm = TRUE)
quantile(GWS_news$TLM, probs = c(.75, .90, .95, 1), na.rm = TRUE)

#News v. Lit

skewness(GWS_Mat$TLM,na.rm = TRUE)
agostino.test(GWS_Mat$TLM)

median(GWS_Mat$TLM,na.rm = TRUE)
median(GWS_news$TLM,na.rm = TRUE)

skewness(GWS_news$TLM,na.rm = TRUE)
agostino.test(GWS_news$TLM)

ks.test(GWS_Mat$TLM, GWS_news$TLM)

#####################Figure 19: Boxplots of Total Length (m) as reported in the media for Carcharadon carcharias by encounter type

GWS_news$GenType <- relevel(droplevels(GWS_news$GenType), ref = "Sighting")
GWS_news$GenType <- factor(GWS_news$GenType, levels = c("Sighting", "Bite", "Fatal"))

ggplot(GWS_news, aes(factor(GenType), TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 19")~italic("Carcharadon carcharias")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Encounter Type")

mean(GWS_news$TLM[GWS_news$GenType == "Sighting"], na.rm = TRUE)
sd(GWS_news$TLM[GWS_news$GenType == "Sighting"], na.rm = TRUE)

mean(GWS_news$TLM[GWS_news$GenType == "Fatal"], na.rm = TRUE)
sd(GWS_news$TLM[GWS_news$GenType == "Fatal"], na.rm = TRUE)

mean(GWS_news$TLM[GWS_news$GenType == "Bite"], na.rm = TRUE)
sd(GWS_news$TLM[GWS_news$GenType == "Bite"], na.rm = TRUE)

mean(GWS_news$TLM[GWS_news$GenType == c("Bite", "Sighting")], na.rm = TRUE)
sd(GWS_news$TLM[GWS_news$GenType == c("Bite", "Sighting")], na.rm = TRUE)

encounter<-lm(GWS_news$TLM~GWS_news$GenType)
summary(encounter)

#####################Figure 20: Boxplots of Total Length (m) for Carcharadon carcharias by Top Sex, Middle Hemisphere, and Bottom Ocean.
GWS_Mat$Sex <- relevel(droplevels(GWS_Mat$Sex), ref = "F")
GWS_Mat$Sex <- factor(GWS_Mat$Sex, levels = c("F", "M"))

p3<-
  ggplot(GWS_Mat, aes(factor(Sex), TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 20")~italic("Carcharadon carcharias")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Sex")

GWS_Mat$Hemisphere <- relevel(droplevels(GWS_Mat$Hemisphere), ref = "N")
GWS_Mat$Hemisphere <- factor(GWS_Mat$Hemisphere, levels = c("N", "S"))

p4<-
  ggplot(GWS_Mat, aes(factor(Hemisphere), TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Hemisphere")

GWS_Mat$GenOcean <- relevel(droplevels(GWS_Mat$GenOcean), ref = "Indian")
GWS_Mat$GenOcean <- factor(GWS_Mat$GenOcean, levels = c("Indian", "Mediterranean", "Atlantic", "Pacific", "Southern"))
GWS_Mat_lm <- lm(GWS_Mat$TLM ~ GWS_Mat$GenOcean)
anova(GWS_Mat_lm)

p5<-
  ggplot(GWS_Mat, aes(factor(GenOcean), TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Ocean")

grid.arrange(p3,p4,p5, ncol=1)


t.test(GWS_Mat$TLM[GWS_Mat$Sex == "F"], GWS_Mat$TLM[GWS_Mat$Sex == "M"])
t.test(GWS_Mat$TLM[GWS_Mat$Hemisphere == "N"], GWS_Mat$TLM[GWS_Mat$Hemisphere == "S"])

#####################Figure 21: Linear regression between Log10 Total Length (m) and Log10 Mass (kg) for Carcharadon carcharias. 
#Log10 Mass= 0.99+3.00 Log10 TL (p<2.2e-16, R2=0.95).
ggplot(GWS_Mat, aes(log10(TLM), log10(WeightKG))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 21")~italic("Carcharadon carcharias")))+
  xlab(expression('Log'[10]~'Total Length (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(0,1)

allometric1<-lm(log10(GWS_Mat$WeightKG) ~ log10(GWS_Mat$TLM))
summary(allometric1)







