#####plots and analyses for Cetorhinus maximus ###########

v
####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

bask<-data.frame(read.csv("Cmaximus.csv", header=TRUE)) #reads in data
bask<-subset(bask, bask$Age != "juvenile")

#####################Figure 16: Distribution of Total Length (m) for Cetorhinus maximus.

ggplot(bask, aes(TLM))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(bold("Figure 16")~italic("Cetorhinus maximus")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(bask$TLM)))))


####################skew, quantiles, summary stats ####################

require(moments)

quantile(bask$TLM, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (bask$TLM, na.rm = TRUE)
agostino.test(bask$TLM)
skewness(bask$TLM,na.rm = TRUE)

#####################Figure 17: Boxplots of Total Length (m) for Cetorhinus maximus by Top Ocean and Bottom Hemisphere.


bask$GenOcean <- relevel(droplevels(bask$GenOcean), ref = "Atlantic")
bask$GenOcean <- factor(bask$GenOcean, levels = c("Atlantic", "Indian", "Mediterranean", "Pacific"))

bask$Hemisphere <- relevel(droplevels(bask$Hemisphere), ref = "N")
bask$Hemisphere <- factor(bask$Hemisphere, levels = c("N", "S"))


p1<-
  ggplot(bask, aes(factor(GenOcean),TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 17")~italic("Cetorhinus maximus")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Ocean")
p2<-
  ggplot(bask, aes(factor(Hemisphere),TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Hemisphere")

grid.arrange(p1,p2,ncol=1)

###analysis
ocn_lm <- lm(bask$TLM ~ bask$GenOcean)
summary(ocn_lm)
t.test(bask$TLM[bask$Hemisphere == "N"], bask$TLM[bask$Hemisphere == "S"])
