#####plots and analyses for Dermochelys coriacea ###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

lb<-read.csv("Dcoriacea.csv", header=TRUE) #reads in data
lb<-data.frame(lb)

lb2<-subset(lb, Weight<900)

##################Figure 34Relationship between Log10 Total Length (m) and Log10 Mass (kg) for Dermochelys coriacea. 
#Log10 Length=2.22+1.25 Log10 Mass (p=0.0329, R2=0.22).

ggplot(lb, aes(log10(CCL), log10(Weight))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 34")~italic("Dermochelys coriacea")))+
  xlab(expression('Log'[10]~'Curved Carapace Length (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(0.1,0.35)


allometric1<-lm(log10(lb2$Weight)~log10(lb2$CCL))
summary(allometric1)

##################Figure 35: Distribution of Curved Carapace Length (m) for Dermochelys coriacea.
ggplot(lb, aes(CCL))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Curved Carapce Length (m)")+
  ggtitle(expression(atop(bold("Figure 35")*italic(" Dermochelys coriacea"))))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(lb$CCL)))))
####################skew, quantiles, summary stats ####################


require(moments)

quantile(lb$CCL, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (lb$CCL, na.rm = TRUE)
skewness(lb$CCL,na.rm = TRUE)
agostino.test(lb$CCL)

lb2<-subset(lb, CCL>0.5)
agostino.test(lb2$CCL)
quantile(lb2$CCL, probs = c(.75, .90, .95, 1), na.rm = TRUE)




