#####plots and analyses for Giant Pacific Octopus (Enteroctopus dofleini)###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

gpo<-read.csv("Edofleini.csv", header=TRUE) #reads in data
gpo<-data.frame(gpo)

###################Figure 11: Top Distribution Mass (kg), Middle distributions of Mass between 0 and 40 kg, and Bottom Interocular Distance (m) for Enteroctopus Dofleini.

p1<-
  ggplot(gpo, aes(Mass..kg.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Mass (kg)")+
  ggtitle(expression(bold("Figure 11")~italic("Enteroctopus dofleini")))+
  ylab("Count")
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(gpo$Mass..kg.)))))

p2<-
  ggplot(gpo, aes(Mass..kg.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Mass (kg)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(gpo$Mass..kg.)))))+
  xlim(-5, 40)

p3<-
  ggplot(gpo, aes(interocular.distance..meters.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Interocular Distance (m)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(gpo$interocular.distance..meters.)))))

grid.arrange(p1,p2,p3, ncol=1)

####################skew, quantiles, summary stats ####################

require(moments)

quantile(gpo$Mass..kg., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (gpo$Mass..kg., na.rm = TRUE)
agostino.test(gpo$Mass..kg.)

quantile(gpo$interocular.distance..meters., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (gpo$interocular.distance..meters., na.rm = TRUE)
agostino.test(gpo$interocular.distance..meters.)

###################Figure 12: Boxplots of differences between male and female Enteroctopus dofleini in Top Mass (kg) and Bottom Interocular Distance (m)
gpo_sex<-subset(gpo, Sex=="M" | Sex=="F")

p4<-
  ggplot(gpo_sex, aes(factor(Sex),Mass..kg.))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=TRUE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 12")~italic("Enteroctopus dofleini")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Mass (kg)")+
  xlab("Sex")+
  ylim(0,30)

p5<-
  ggplot(gpo_sex, aes(factor(Sex),interocular.distance..meters.))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=TRUE)+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Interocular Distance (m)")+
  xlab("Sex")

grid.arrange(p4,p5,ncol=1)


sex_mass<-lm(gpo$Mass..kg.~gpo$Sex)
summary(sex_mass)

sex_IOD<-lm(gpo$interocular.distance..meters.~gpo$Sex)
summary(sex_IOD)



############Figure 13: Linear regression between Log10 Interocular Distance (m) and Log10 Mass (kg) for Enteroctopus dofleini. 
#Log10 Mass=3.61 +2.64 Log10 IOD (p<2.2e-16, R2=0.72).

allometric1<-lm(log10(gpo$Mass..kg.)~log10(gpo$interocular.distance..meters.))
summary(allometric1)

ggplot(gpo, aes(log10(interocular.distance..meters.), log10(Mass..kg.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 13")~italic("Enteroctopus dofleini")))+
  xlab(expression('Log'[10]~'Interocular Distance (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(-1.3, -.7)+
  ylim(-.3, 1.75)


