#####plots and analyses for Hexanchus griseus ###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

griseus <- data.frame(read.csv("Hgriseus.csv", header=TRUE))
griseus_Mat <- data.frame(subset(griseus, griseus$Maturity != "immature")) 

#####################Figure 24: Distribution of Top Total Length (m) and Bottom Mass (kg) for Hexanchus griseus

p1<-
  ggplot(griseus_Mat, aes(TLM))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(bold("Figure 24")*italic(" Hexanchus griseus")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(griseus_Mat$TLM)))))

p2<-
  ggplot(griseus_Mat, aes(WeightKG))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Mass (kg)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(griseus_Mat$WeightKG)))))

grid.arrange(p1,p2, ncol=1)

####################skew, quantiles, summary stats ####################

require(moments)

skewness(griseus_Mat$TLM,na.rm = TRUE)

quantile(griseus_Mat$TLM, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (griseus_Mat$TLM, na.rm = TRUE)
agostino.test(griseus_Mat$TLM)

skewness(griseus_Mat$WeightKG,na.rm = TRUE)

quantile(griseus_Mat$WeightKG, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (griseus_Mat$WeightKG, na.rm = TRUE)
agostino.test(griseus_Mat$WeightKG)


#####################Figure 25: Linear regression between Log10 Total Length (m) and Log10 Mass (kg) for Hexanchus griseus. 
#Log10 Mass = 0.67+3.33 Log10 TL (p<2.2e-16, R2=0.92).

allometric1 <- lm(log10(griseus_Mat$WeightKG) ~ log10(griseus_Mat$TLM), na.action = na.exclude)
summary(allometric1)


ggplot(griseus_Mat, aes(log10(TLM), log10(WeightKG))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 25")~italic("Hexanchus griseus")))+
  xlab(expression('Log'[10]~'Total Length (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(0,.5)


