#####plots and analyses for Mantra birostris###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

manta<-data.frame(read.csv("Mbirostris.csv", header=TRUE))
manta_mozam<-data.frame(subset(manta, Region== "Mozambique"))
manta_ecu<-data.frame(subset(manta, Region== "Ecuador"))

###################Figure 26: Distribution of Disc Width (m) for Manta birostris by measurement method.

ggplot(manta, aes(DW..m.))+
  facet_grid(Method ~ ., scales = "free_y")+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Disc Width (m)")+
  ggtitle(expression(atop(bold("Figure 26")*italic(" Mantra birostris"))))+
  ylab("Count")

###################Figure 27: Boxplots of Disc Width (m) for Manta birostris by region.

ggplot(manta, aes(factor(Sex), DW..m.))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 27")~italic("Mantra birostris")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Disc Width (m)")+
  xlab("Sex")

###################Figure 28: Boxplots of Disc Width (m) for Manta birostris by sex.

ggplot(manta, aes(factor(Region), DW..m.))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 28")~italic("Mantra birostris")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Disc Width (m)")+
  xlab("Region")

####################skew, quantiles, summary stats ####################

require(moments)

quantile(manta$DW..m., probs = c(.75, .90, .95, 1), na.rm = TRUE)
quantile(manta_ecu$DW..m., probs = c(.75, .90, .95, 1), na.rm = TRUE)
quantile(manta_mozam$DW..m., probs = c(.75, .90, .95, 1), na.rm = TRUE)


agostino.test(manta$DW..m.)
agostino.test(manta_ecu$DW..m.)
agostino.test(manta_mozam$DW..m.)


manta_test<-lm(data=manta, DW..m.~Sex+Method+Region)
summary(manta_test)
