#####plots and analyses for Mirounga leonina ###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

Mleonina <- read.csv("Mleonina.csv", header=TRUE) #reads in data
Mleonina<-subset(Mleonina, TLM>1)

#####################Figure 36:Distribution of Total Length (m) for Mirounga leonina


ggplot(Mleonina, aes(TLM))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(bold("Figure 36")*italic(" Mirounga leonina")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(Mleonina$TLM)))))



####################skew, quantiles, summary stats ####################
require(moments)

quantile(Mleonina$TLM, probs = c(0.49, .75, .90, .95, 1), na.rm = TRUE)
skewness(Mleonina$TLM,na.rm = TRUE)
agostino.test(Mleonina$TLM)

median(Mleonina$TLM,na.rm = TRUE)

#####################Figure 37:Distribution of Total Length (m) for Mirounga leonina



Mleonina$Sex <- relevel(droplevels(Mleonina$Sex), ref = "F")
Mleonina$Sex <- factor(Mleonina$Sex, levels = c("F", "M"))

Mleonina_sex<-subset(Mleonina, Sex=="M" | Sex=="F")

ggplot(Mleonina_sex, aes(factor(Sex), TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  facet_wrap(~SpecLoc)+
  ggtitle(expression(bold("Figure 37")~italic("Mirounga leonina")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Sex")


sex_analysis<-lm(data=Mleonina, TLM~Sex+SpecLoc)
summary(sex_analysis)
anova(sex_analysis)


