#####plots and analyses for Mola mola###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

mola<-data.frame(read.csv("Mmola.csv", header=TRUE)) #reads in data



###################Figure 31: Distribution of Top Total Length (m) and Bottom Mass (kg) for Mola mola


p1<-
  ggplot(mola, aes(Total.Length_m))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(atop(bold("Figure 31")*italic(" Mola mola"))))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(mola$Total.Length_m)))))

p2<-
  ggplot(mola, aes(Weight_kg))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Weight (kg)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(mola$Weight_kg)))))

grid.arrange(p1,p2, ncol=1)


####################skew, quantiles, summary stats ####################

require(moments)

quantile(mola$Total.Length_m, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (mola$Total.Length_m, na.rm = TRUE)
agostino.test(mola$Total.Length_m)

quantile(mola$Weight_kg, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (mola$Weight_kg, na.rm = TRUE)
agostino.test(mola$Weight_kg)

###################Figure 32: Boxplots of Top Total Length (m) and Bottom Mass (kg) for Mola mola by Ocean

p3<-ggplot(mola, aes(factor(Ocean), Total.Length_m))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 32")~italic("Mola mola")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Ocean")

p4<-ggplot(mola, aes(factor(Ocean), Weight_kg))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Weight (kg)")+
  xlab("Ocean")

grid.arrange(p3,p4, ncol=1)

###################Figure 33: Linear regressions for Mola mola. 
#Top Log10 Total Length (m) and Log10 Mass (kg). Log10 Length=1.82+3.19 Log10 Mass (p<2.2e-16, R2=0.94). 
#Middle Log10 Doral to Anal Fin Height (m) and Log10 Mass (kg). Log10 DAFLength=1.24+2.55 Log10 Mass (p<2.2e-16, R2=0.58). 
#Bottom Log10 Doral to Anal Fin Height (m) and Log10 Total Length (m). Log10 DAFLength=-0.13+1.03 Log10 Length (p<2.2e-16, R2=0.89).

p5<-
  ggplot(mola, aes(log10(Total.Length_m), log10(Weight_kg))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 33")~italic("Mola mola")))+
  xlab(expression('Log'[10]~'Total Length (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))
p6<-
  ggplot(mola, aes(log10(Dorsal.to.anal.fin.height_m), log10(Weight_kg))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  xlab(expression('Log'[10]~'Dorsal to Anal Fin Height (m)'))+
  ylab(expression('Log'[10]~'Mass (kg)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))

p7<-
  ggplot(mola, aes(log10(Dorsal.to.anal.fin.height_m), log10(Total.Length_m))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  xlab(expression('Log'[10]~'Dorsal to Anal Fin Height (m)'))+
  ylab(expression('Log'[10]~'Total Length (m)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))


grid.arrange(p5,p6,p7, ncol=1)

#analyses
allometric1<-lm(log10(mola$Weight_kg)~log10(mola$Total.Length_m), na.action=na.exclude)
summary(allometric1)

allometric2<-lm(log10(mola$Weight_kg)~log10(mola$Dorsal.to.anal.fin.height_m), na.action=na.exclude)
summary(allometric2)

allometric3<-lm(log10(mola$Total.Length_m)~log10(mola$Dorsal.to.anal.fin.height_m), na.action=na.exclude)
summary(allometric3)
