#####plots and analyses for Odobenus rosmarus ###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)
require(plyr)

####################load and summarize data####################


walrus<-read.csv("Orosmarus.csv", header=TRUE) #reads in data
walrus<-data.frame(walrus)

divergens<-subset(walrus, walrus$Name.used=="Odobenus rosmarus divergens")
rosmarus<-subset(walrus, walrus$Name.used=="Odobenus rosmarus rosmarus ")

##################Figure 38: Distribution of Top Total Length (m) and Bottom Mass (kg) for Odobenus rosmarus

p1<-ggplot(walrus, aes(Standard.Length..meters.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Standard Length (m)")+
  ggtitle(expression(atop(bold("Figure 38")*italic(" Odobenus rosmarus"))))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(walrus$Standard.Length..meters.)))))

p2<-ggplot(walrus, aes(Mass..kg.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Mass (kg)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(walrus$Mass..kg.)))))


grid.arrange(p1,p2, ncol=1)

####################skew, quantiles, summary stats ####################

require(moments)

quantile(walrus$Standard.Length..meters., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (walrus$Standard.Length..meters., na.rm = TRUE)
agostino.test(walrus$Standard.Length..meters.)

quantile(walrus$Mass..kg., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (walrus$Mass..kg., na.rm = TRUE)
agostino.test(walrus$Mass..kg.)

##################Figure 39: Boxplots of Top Total Length (m) and Bottom Mass (kg) for Odobenus rosmarus 
#divided by subspecies and sex.

p3<-ggplot(walrus, aes(factor(Sex),Standard.Length..meters.))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  facet_grid(. ~ Name.used)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 39")~italic("Odobenus rosmarus")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Length (m)")+
  xlab("Sex")

p4<-ggplot(walrus, aes(factor(Sex),Mass..kg.))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  facet_grid(. ~ Name.used)+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Mass (kg)")+
  xlab("Sex")

grid.arrange(p3,p4, ncol=1)

#analysis
walrus_SL<-lm(walrus$Standard.Length..meters.~walrus$Name.used + walrus$Sex)
summary(walrus_SL)

walrus_mass<-lm(walrus$Mass..kg.~walrus$Name.used + walrus$Sex)
summary(walrus_mass)







