#####plots and analyses for Physeter macrocephalus  ###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)
require(plyr)

####################load and summarize data####################

swna<-read.csv("Pmacrocephlus_na.csv", header=TRUE)
swnp<-read.csv("Pmacrocephlus_np.csv", header=TRUE)
swsa<-read.csv("Pmacrocephlus_sa.csv", header=TRUE)
swshp1<-read.csv("Pmacrocephlus_shp1.csv", header=TRUE)
swshp2<-read.csv("Pmacrocephlus_shp2.csv", header=TRUE)
swshsg<-read.csv("Pmacrocephlus_shsg.csv", header=TRUE)
swshss<-read.csv("Pmacrocephlus_shss.csv", header=TRUE)
swsp<-read.csv("Pmacrocephlus_sp.csv", header=TRUE)
swio<-read.csv("Pmacrocephlus_ioedited.csv",header=TRUE)

sperm<-data.frame(rbind(swna, swnp, swsa, swshp1, swshp2, swshsg, swshss, swsp, swio))

sperm$Sx <- mapvalues(sperm$Sx, from = c("1", "2", "3", "0"), to = c("Male", "Female", "Hermaphrodite", "Unknown"))
sperm$Ocean <-mapvalues(sperm$Ocean, from = "Southern Hemisphere Pelagic", to ="S.H. Pelagic")
sperm$Ocean <- factor(sperm$Ocean, levels = c("South Pacific","Indian","South Atlantic", 
                                              "North Pacific", "North Atlantic", "S.H. Pelagic",
                                              "South Georgia", "South Shetlands"))

sperm_sex<-subset(sperm, Sx=="Male" | Sx=="Female")


####################skew, quantiles, summary stats ####################

max(sperm$Lengthmeters, na.rm=TRUE)
sperm[which.max(sperm$Lengthmeters),]

#next largest
sperm_L<-na.omit(sperm$Lengthmeters)
n <- length(sperm_L)
sort(sperm_L,partial=n-8, na.last=TRUE)[n-8]

require(moments)


quantile(sperm$Lengthmeters, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (sperm$Lengthmeters, na.rm = TRUE)
skewness(sperm$Lengthmeters,na.rm = TRUE)

##################Figure 40: Distribution of Total Length (m) for Physeter macrocephalus

ggplot(sperm, aes(Lengthmeters))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(atop(bold("Figure 40")*italic(" Physeter macrocephalus"))))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(sperm$Lengthmeters)))))

##################Figure 41: Boxplots of Total Length (m) by region and sex for Physeter macrocephalus

Zissou <- c("darkorange", "lightsteelblue")

ggplot(sperm_sex, aes(factor(Sx),Lengthmeters, fill=Sx))+
  geom_boxplot(notch=FALSE)+
  scale_fill_manual(values=Zissou)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 41")~italic("Physeter macrocephalus")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"),
        axis.text.x=element_blank(), 
        strip.text.x=element_text(angle=90))+
  ylab("Total Length (m)")+
  xlab("")+
  facet_grid(.~Ocean)


##################Figure 42: Total Length (m) verses year by region for Physeter macrocephalus

ggplot(sperm_sex, aes(Yr, Lengthmeters)) +
  geom_point(shape=., color="lightsteelblue3")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 42")~italic("Physeter macrocephalus")))+
  xlab("Year")+
  ylab("Total Length (m)")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"),strip.text.y=element_text(angle=0))+
  facet_grid(Ocean ~ ., scales="free_y")
    
##################Analysis############################

sperm_analysis<-lm(data=sperm_sex, Lengthmeters~Sx+Yr+Ocean+Sx*Yr+Sx*Ocean+Yr*Ocean)
summary(sperm_analysis)
