#####plots and analyses for Regalecus glesne###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

oarfish<-read.csv("Rglesne.csv", header=TRUE) #reads in data
oarfish<-data.frame(oarfish)

###################Figure 29: Distribution of Total Length (m) for Regalecus glesne by measurement method.

ggplot(oarfish, aes(Length_m))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(atop(bold("Figure 29")*italic(" Regalecus glesne"))))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(oarfish$Length_m)))))+
  xlim(0, 8)


####################skew, quantiles, summary stats ####################
require(moments)

quantile(oarfish$Length_m, probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (oarfish$Length_m, na.rm = TRUE)
agostino.test(oarfish$Length_m)

###################Figure 30: Boxplots of Disc Width (m) for Regalecus glesne by region.

oarfish$Location2 <- factor(oarfish$Location2, levels = c("NW Atlantic","Mediterranean","South Africa", 
                                                          "Australia", "Gulf of Mexio", "Caribbean", "Indian Ocean", "NE Pacific",
                                                          "British Isles", "Scandanavia", "New Zealand", "Western Europe" ))

ggplot(oarfish, aes(factor(Location2), Length_m))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 30")~italic("Regalecus glesne")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Region")+
  opts(axis.text.x=theme_text(angle=-90))

