#####plots and analyses for Syrinx aruanus###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

syrinx_lit<-read.csv("Saruanus_data.csv", header=TRUE) #reads in data
syrinx_sales<-read.csv("Saruanus_sales.csv", header=TRUE)

#length coversion to cm
syrinx_lit$Shell_length_cm<-syrinx_lit$Shell.length..mm./10
syrinx_sales$Shell_length_cm<-syrinx_sales$ShellLength_inches*2.54


###################Figure 9: Distributions of Shell Length (cm) from Top the literature and museum collections and Bottom from online sales for Syrinx aruanus.

p1<-
  ggplot(syrinx_lit, aes(Shell_length_cm))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Shell Length (cm)")+
  ggtitle(expression(atop(bold("Figure 9")*italic(" Syrinx aruanus"),"Literature & Musuem Collections")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(syrinx_lit$Shell_length_cm)))))+
  xlim(-5, 80)

p2<-
  ggplot(syrinx_sales, aes(Shell_length_cm))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Shell Length (cm)")+
  ggtitle("Online Sales")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(syrinx_sales$Shell_length_cm)))))+
  xlim(-5, 80)

grid.arrange(p1,p2, ncol=1)


####################skew, quantiles, summary stats ####################

mean(syrinx_lit$Shell_length_cm, na.rm = TRUE)
mean(syrinx_sales$Shell_length_cm, na.rm = TRUE)

median(syrinx_lit$Shell_length_cm, na.rm=TRUE)
median(syrinx_sales$Shell_length_cm, na.rm = TRUE)

require(moments)

agostino.test(syrinx_lit$Shell_length_cm)
agostino.test(syrinx_sales$Shell_length_cm)
quantile(syrinx_lit$Shell_length_cm, probs = c(.75, .90, .95, 1), na.rm = TRUE)
quantile(syrinx_sales$Shell_length_cm, probs = c(.75, .90, .95, 1), na.rm = TRUE)



###################Figure 10: Linear regression between Log10 Shell Length (cm) and Log10 Price (US$) for Syrinx aruanus. 
#Log10 Price=0.21+1.09 Log10 Length (p=2.387e-07, R2=0.35)

ggplot(syrinx_sales, aes(log10(Shell_length_cm), log10(Price))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 10")~italic("Syrinx aruanus")))+
  xlab(expression('Log'[10]~'Shell Length (cm)'))+
  ylab(expression(paste('Log'[10],' Price (US$)')))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlim(1.3,1.8)

money_fit<-lm(log10(syrinx_sales$Price)~log10(syrinx_sales$Shell_length_cm))
summary (money_fit)

