#####plots and analyses for Somniosus microcephalus###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

grnlnd<-data.frame(read.csv("Smicrocephalus.csv", header=TRUE)) #reads in data

#####################Figure 22: Distribution of Total Length (m) for Somniosus microcephalus

ggplot(grnlnd, aes(TLM))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Total Length (m)")+
  ggtitle(expression(bold("Figure 22")*italic(" Somniosus microcephalus")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(grnlnd$TLM)))))


####################skew, quantiles, summary stats ####################
require(moments)

quantile(grnlnd$TLM, probs = c(.75, .90, .95, 1), na.rm = TRUE)
skewness(grnlnd$TLM,na.rm = TRUE)
agostino.test(grnlnd$TLM)
median(grnlnd$TLM,na.rm = TRUE)



####################Figure 23: Boxplots of Total Length (m) for Somniosus microcephalus by sex
sex_lm <- lm(grnlnd$TLM ~ grnlnd$Sex)
summary(sex_lm)
anova(sex_lm)
t.test(grnlnd$TLM[grnlnd$Sex == "M"], grnlnd$TLM[grnlnd$Sex == "F"])

grnlnd_sex<-subset(grnlnd, Sex=="M" | Sex=="F")


ggplot(grnlnd_sex, aes(factor(Sex), TLM))+
  geom_boxplot(color="black", fill="lightsteelblue", notch=FALSE)+
  theme_bw(base_size=18)+
  ggtitle(expression(bold("Figure 23")~italic("Somniosus microcephalus")))+
  theme(panel.grid.major = element_line(size = .2, color = "grey"))+
  ylab("Total Length (m)")+
  xlab("Sex")
