#####plots and analyses for Tridacna gigas###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

tgigas_Lit<-read.csv("Tgigas_data.csv", header=TRUE) #reads in data
tgigas_Lit<-data.frame(tgigas_Lit)

tgigas_PM<-read.csv("Tgigas_pearson.csv", header=TRUE)
tgigas_PM<-data.frame(tgigas_PM)

tgigas_Sales<-read.csv("Tgigas_sales.csv", header=TRUE) #reads in data
tgigas_Sales$ShellLengthcm = tgigas_Sales$ShellLength_inches * 2.54
tgigas_Sales$Shellwidthcm = tgigas_Sales$ShellWidth_inches * 2.54
tgigas_Sales<-data.frame(tgigas_Sales)

#####################Figure 6: Distribution of Shell Length (cm) from a 
#Top literature survey, Middle a census by Pearson and Munro (1991), and Bottom online sales for Tridacna gigas.

p1<-
  ggplot(tgigas_Lit, aes(Shell.length..cm.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Shell Length (cm)")+
  ggtitle(expression(atop(bold("Figure 6")*italic(" Tridacna gigas"),"Literature")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(tgigas_Lit$Shell.length..cm.)))))+
  xlim(-5, 150)

p2<-
  ggplot(tgigas_PM, aes(ShellLength))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Shell Length (cm)")+
  ggtitle("Pearson and Munro (1991)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(tgigas_PM$ShellLength)))))+
  xlim(-5, 150)

p3<-
  ggplot(tgigas_Sales, aes(ShellLengthcm))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Shell Length (cm)")+
  ggtitle("Online Sales")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(tgigas_Sales$ShellLengthcm)))))+
  xlim(-5, 150)

grid.arrange(p1,p2,p3, ncol=1)

####################skew, quantiles, summary stats ####################
require(moments)

agostino.test(tgigas_Lit$Shell.length..cm)
agostino.test(tgigas_PM$ShellLength)
agostino.test(tgigas_Sales$ShellLengthcm)

quantile(tgigas_Lit$Shell.length..cm, probs = c(.75, .90, .95, 1), na.rm = TRUE)
quantile(tgigas_PM$ShellLength, probs = c(.75, .90, .95, 1), na.rm = TRUE)
quantile(tgigas_Sales$ShellLengthcm, probs = c(.75, .90, .95, 1), na.rm = TRUE)


#####################Figure 7: Linear regression between Log10 Shell Length (cm) and Log10 Price (US$) for Tricdacna gigas. 
#Log10 Cost=-1.30+2.32 Log10 (p<2.2e-16, R2=0.80)

ggplot(tgigas_Sales, aes(log10(ShellLengthcm), log10(Price))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 7")~italic("Tridacna gigas")))+
  xlab(expression('Log'[10]~'Shell Length (cm)'))+
  ylab(expression('Log'[10]~'Price (US$)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))

allometric3<-lm(log10(tgigas_Sales$Price)~log10(tgigas_Sales$ShellLengthcm))
summary(allometric3)
#########Figure 8: Linear regression between Shell Width (cm) and Shell Length (cm) from online sales (Width=0.53+0.64 Length, p<2.2e-16, R2=0.95, Blue) 
#and from natural populations (Width=4.77+0.49 Length, p<2.2e-16, R2=0.88, Orange) for Tridacna gigas.

ggplot(tgigas_Sales, aes(ShellLengthcm, Shellwidthcm)) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_point(data=tgigas_Lit, aes(Shell.length..cm.,Width..cm.), shape=21, size=5, fill="darkorange")+
  geom_smooth(data=tgigas_Lit, mapping=aes(Shell.length..cm.,Width..cm.), method=lm,se=FALSE, color="darkorange")+
  geom_smooth(data=tgigas_Sales, mapping=aes(ShellLengthcm, Shellwidthcm), method=lm,se=FALSE, color="lightsteelblue")+
  ggtitle(expression(bold("Figure 8")~italic("Tridacna gigas")))+
  xlab("Shell Length (cm)")+
  ylab("Width (cm)")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))




allometric1<-lm(tgigas_Sales$Shellwidthcm~tgigas_Sales$ShellLengthcm)
allometric2<-lm(tgigas_Lit$Width..cm.~tgigas_Lit$Shell.length..cm.)

summary(allometric1)
summary(allometric2)
