#####plots and analyses for Xestospongia muta###########

setwd("~yourdir")

####call packages####
require(ggplot2)
require(ggthemes)
require(grid)
require(gridExtra)

####################load and summarize data####################

sponge<-read.csv("Xmuta.csv", header=TRUE) #reads in data
sponge<-data.frame(sponge)

###################Figure 1:  Linear regression between Log10 Base Diameter (m) and Log10 Volume (cm3) for Xestospongia muta.  
#Log10 Volume=5.65 + 3.05 Log10 Base Diameter (p<2.2e-16, R2=0.95)


ggplot(sponge, aes(log10(Base.Diameter..meters.), log10(Sponge.Volume..cm.3.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 1")~italic("Xestospongia muta")))+
  xlab(expression('Log'[10]~'Base Diameter (m)'))+
  ylab(expression(paste('Log'[10],' Volume (cm'^3,')')))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))

##analysis for relationship##
allometric4<-lm(log10(sponge$Sponge.Volume..cm.3.)~log10(sponge$Base.Diameter..meters.))
summary(allometric4)

#####################Figure 2: Distribution of Top Base diameter (m), Middle Height (m), and Bottom Volume (cm3) for Xestospongia muta

p1<-
  ggplot(sponge, aes(Base.Diameter..meters.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Base Diameter (m)")+
  ggtitle(expression(bold("Figure 2")~italic("Xestospongia muta")))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(sponge$Base.Diameter..meters.)))))
  
p2<-
  ggplot(sponge, aes(Height..meters.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab("Height (m)")+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(sponge$Height..meters.)))))

p3<-
  ggplot(sponge, aes(Sponge.Volume..cm.3.))+
  geom_histogram(color="black", fill="lightsteelblue")+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))+
  xlab(expression(paste('Volume (cm'^3,')')))+
  ylab("Count")+
  annotate("text", x=Inf,hjust=2, y = Inf,vjust=3, label=paste("N=",toString(length(na.omit(sponge$Sponge.Volume..cm.3.)))))

grid.arrange(p1,p2,p3, ncol=1)


####################skew, quantiles, summary stats ####################
require(moments)

quantile(sponge$Base.Diameter..meters., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (sponge$Base.Diameter..meters., na.rm = TRUE)
skewness(sponge$Base.Diameter..meters.,na.rm = TRUE)
agostino.test(sponge$Base.Diameter..meters.)

quantile(sponge$Height..meters., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (sponge$Height..meters., na.rm = TRUE)
skewness(sponge$Height..meters., na.rm=TRUE)
agostino.test(sponge$Height..meters.)

quantile(sponge$Sponge.Volume..cm.3., probs = c(.75, .90, .95, 1), na.rm = TRUE)
median (sponge$Sponge.Volume..cm.3., na.rm = TRUE)
skewness(sponge$Sponge.Volume..cm.3., na.rm=TRUE)
agostino.test(sponge$Sponge.Volume..cm.3.)

####################Figure 3: Allometric equations for Xestospongia muta. 
#Top Log10 Base Diameter (m) and Log10 Height (m). Log10 Osculum Diameter=-0.01+0.68 Log10 Base Diameter (p<2.2e-16, R2=0.77) 
#Middle Log10 Average Osculum Diameter (m) and Log10 Base Diameter (m). Log10 Osculum Diameter=-0.01+0.68 Log10 Base Diameter (p<2.2e-16, R2=0.81) 
#Bottom Log10 Average Osculum Diameter (m) and Log10 Height (m). Log10 Osculum Diameter=0.05+0.75 Log10 Height (p<2.2e-16, R2=0.74)

p4<-
  ggplot(sponge, aes(log10(Base.Diameter..meters.), log10(Height..meters.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ggtitle(expression(bold("Figure 3")~italic("Xestospongia muta")))+
  xlab(expression('Log'[10]~'Base Diameter (m)'))+
  ylab(expression('Log'[10]~'Height (m)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))

p5<-
  ggplot(sponge, aes(log10(Average.Osculum.Diameter..m.), log10(Base.Diameter..meters.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ylab(expression('Log'[10]~'Base Diameter (m)'))+
  xlab(expression('Log'[10]~'Average Osculum Diameter (m)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))

p6<-
  ggplot(sponge, aes(log10(Average.Osculum.Diameter..m.), log10(Height..meters.))) +
  geom_point(shape=21, size=5, fill="lightsteelblue")+
  geom_smooth(method=lm,se=FALSE, color="black")+
  ylab(expression('Log'[10]~'Height (m)'))+
  xlab(expression('Log'[10]~'Average Osculum Diameter (m)'))+
  theme_bw(base_size=18)+
  theme(panel.grid.major = element_line(size = .5, color = "grey"))

grid.arrange(p4,p5,p6, ncol=1)
  

#analyses
allometric1<-lm(log10(sponge$Height..meters.)~log10(sponge$Base.Diameter..meters.))

allometric2<-lm(log10(sponge$Base.Diameter..meters.)~log10(sponge$Average.Osculum.Diameter..m.))

allometric3<-lm(log10(sponge$Height..meters.)~log10(sponge$Average.Osculum.Diameter..m.))

summary(allometric1)
summary(allometric2)
summary(allometric3)



